==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/sk.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Nemôžete odobrať vaše vlastné práva na čítanie.",
    "Team folders" : "Tímové adresáre",
    "Admin configured folders shared with everyone in a team" : "Správca nakonfiguroval adresáre zdieľané s každým v tíme",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Administrátorom nakonfigurované adresáre zdieľané s každým v tíme.\n\nAdresáre je možné konfigurovať z *Tímových adresárov* v nastaveniach administrátora.\n\nPo vytvorení adresára môže administrátor poskytnúť prístup k adresáru jednému alebo viacerým tímom, ovládať ich povolenia na zápis/zdieľanie a prideliť adresáru kvótu.\nOd Hub 10/Nextcloud 31 musí byť administrátor súčasťou tímu, aby mu mohol priradiť adresár Team.",
    "Unset" : "Zrušiť",
    "Denied (Inherited permission)" : "Zamietnuté (zdedené oprávnenie)",
    "Allowed (Inherited permission)" : "Povolené (zdedené oprávnenie)",
    "Denied" : "Zamietnuté",
    "Allowed" : "Povolené",
    "Access denied" : "Prístup zamietnutý",
    "Access allowed" : "Prístup povolený ",
    "Inherit permission" : "Dediť oprávnenie",
    "Deny" : "Zamietnuť",
    "Allow" : "Povoliť",
    "Group" : "Skupina",
    "Team" : "Tím",
    "Team folder" : "Tímový adresár",
    "Read" : "Čítať",
    "Write" : "Zapisovať",
    "Create" : "Vytvárať",
    "Delete" : "Mazať",
    "Share" : "Sprístupňovať",
    "You" : "Vy",
    "Remove access rule" : "Odobrať pravidlo prístupu",
    "Add advanced permission rule" : "Pridať pravidlo rozšírených oprávnení",
    "Select a user or group" : "Vyberte používateľa alebo skupinu",
    "Open Team folder" : "Otvoriť Tímový adresár",
    "Permission denied. User does not have sufficient permissions." : "Prístup zamietnutý. Používateľ nemá dostatočné oprávnenia.",
    "Unexpected status from server" : "Neočakávaný stav zo servera",
    "List of Team folders." : "Zoznam Tímových adresárov.",
    "No Team folders yet" : "Nie sú tu zatiaľ žiadne Tímové adresáre",
    "Team folders will show up here" : "Tímové adresáre sa zobrazia tu",
    "Add group" : "Pridať skupinu",
    "Default" : "Predvolené",
    "Unlimited" : "Neobmedzené",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Ste si istý, že chcete zmazať \"{folderName}\" a všetky súbory v ňom? Táto operácia sa nedá vrátiť",
    "Delete \"{folderName}\"?" : "Zmazať \"{folderName}\"?",
    "Team folder admin delegation" : "Delegácia správcu Tímového adresára",
    "They will have access to all Team folders." : "Budú mať prístup ku všetkým Tímovým adresárom.",
    "They will only have access to Team folders for which they have advanced permissions." : "Budú mať prístup iba k Tímovým adresárom, pre ktoré majú pokročilé oprávnenia.",
    "Group or team" : "Skupina alebo tím",
    "Folder name" : "Názov priečinka",
    "Quota" : "Kvóta",
    "Advanced Permissions" : "Rozšírené oprávnenia",
    "Previous" : "Predchádzajúce",
    "Next" : "Ďalšie",
    "User" : "Používateľ",
    "Unknown" : "Neznámy",
    "Users/groups that can manage" : "Užívatelia/skupiny ktoré môžu spravovať",
    "None" : "Žiadne",
    "No other groups or teams available" : "Žiadne ďalšie skupiny alebo tímy nie su dostupné",
    "No other groups available" : "Žiadne ďalšie skupiny nie su dostupné",
    "{displayName} (team)" : "{displayName} (tím)",
    "Add group or team" : "Pridať skupinu alebo tím",
    "{size} used" : "{size} použité",
    "You can not remove your own read permission." : "Nemôžete odobrať vaše vlastné práva na čítanie.",
    "Group folders" : "Skupinové priečinky",
    "Admin configured folders shared with everyone in a group" : "Správcom nastavené priečinky, zdieľané s každým v skupine",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Správcom nakonfigurované adresáre zdieľané s každým v skupine.\n\nAdresáre je možné konfigurovať z *Adresáre skupiny* v nastaveniach správcu.\n\nPo vytvorení adresára môže správca poskytnúť prístup k adresáru jednej alebo viacerým skupinám, riadiť ich povolenia na zápis/zdieľanie a prideliť adresáru kvótu.",
    "Group folder" : "Skupinový priečinok",
    "Open group folder" : "Otvoriť adresár skupiny",
    "List of group folders." : "Zoznam skupinových adresárov.",
    "No group folders yet" : "Žiadne skupinové adresáre",
    "Group folders will show up here" : "Skupinové adresáre sa zobrazia tu",
    "Group folder admin delegation" : "Delegácia správcu skupinového adresára",
    "They will have access to all group folders." : "Budú mať prístup ku všetkým skupinovým adresárom.",
    "They will only have access to group folders for which they have advanced permissions." : "Budú mať prístup iba k skupinovým adresárom, pre ktoré majú pokročilé oprávnenia.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Správca nakonfiguroval adresáre zdieľané s každým v tíme.\n\nAdresáre je možné konfigurovať z *Tímových adresárov* v nastaveniach správcu.\n\nPo vytvorení adresára môže správca poskytnúť prístup k adresáru jednému alebo viacerým tímom, ovládať ich povolenia na zápis/zdieľanie a prideliť adresáru kvótu."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/sk.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Nemôžete odobrať vaše vlastné práva na čítanie.",
    "Team folders" : "Tímové adresáre",
    "Unset" : "Zrušiť",
    "Denied (Inherited permission)" : "Zamietnuté (zdedené oprávnenie)",
    "Allowed (Inherited permission)" : "Povolené (zdedené oprávnenie)",
    "Denied" : "Zamietnuté",
    "Allowed" : "Povolené",
    "Access denied" : "Prístup zamietnutý",
    "Access allowed" : "Prístup povolený ",
    "Inherit permission" : "Dediť oprávnenie",
    "Deny" : "Zamietnuť",
    "Allow" : "Povoliť",
    "Group" : "Skupina",
    "Team" : "Tím",
    "Team folder" : "Tímový adresár",
    "Read" : "Čítať",
    "Write" : "Zapisovať",
    "Create" : "Vytvárať",
    "Delete" : "Mazať",
    "Share" : "Sprístupňovať",
    "You" : "Vy",
    "Remove access rule" : "Odobrať pravidlo prístupu",
    "Add advanced permission rule" : "Pridať pravidlo rozšírených oprávnení",
    "Select a user or group" : "Vyberte používateľa alebo skupinu",
    "Open Team folder" : "Otvoriť Tímový adresár",
    "Permission denied. User does not have sufficient permissions." : "Prístup zamietnutý. Používateľ nemá dostatočné oprávnenia.",
    "Unexpected status from server" : "Neočakávaný stav zo servera",
    "List of Team folders." : "Zoznam Tímových adresárov.",
    "No Team folders yet" : "Nie sú tu zatiaľ žiadne Tímové adresáre",
    "Team folders will show up here" : "Tímové adresáre sa zobrazia tu",
    "Add group" : "Pridať skupinu",
    "Default" : "Predvolené",
    "Unlimited" : "Neobmedzené",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Ste si istý, že chcete zmazať \"{folderName}\" a všetky súbory v ňom? Táto operácia sa nedá vrátiť",
    "Delete \"{folderName}\"?" : "Zmazať \"{folderName}\"?",
    "Team folder admin delegation" : "Delegácia správcu Tímového adresára",
    "They will have access to all Team folders." : "Budú mať prístup ku všetkým Tímovým adresárom.",
    "They will only have access to Team folders for which they have advanced permissions." : "Budú mať prístup iba k Tímovým adresárom, pre ktoré majú pokročilé oprávnenia.",
    "Group or team" : "Skupina alebo tím",
    "Folder name" : "Názov priečinka",
    "Quota" : "Kvóta",
    "Advanced Permissions" : "Rozšírené oprávnenia",
    "Previous" : "Predchádzajúce",
    "Next" : "Ďalšie",
    "User" : "Používateľ",
    "Unknown" : "Neznámy",
    "Users/groups that can manage" : "Užívatelia/skupiny ktoré môžu spravovať",
    "None" : "Žiadne",
    "No other groups or teams available" : "Žiadne ďalšie skupiny alebo tímy nie su dostupné",
    "No other groups available" : "Žiadne ďalšie skupiny nie su dostupné",
    "{displayName} (team)" : "{displayName} (tím)",
    "Add group or team" : "Pridať skupinu alebo tím",
    "{size} used" : "{size} použité",
    "You can not remove your own read permission." : "Nemôžete odobrať vaše vlastné práva na čítanie.",
    "Group folders" : "Skupinové priečinky",
    "Admin configured folders shared with everyone in a group" : "Správcom nastavené priečinky, zdieľané s každým v skupine",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Správcom nakonfigurované adresáre zdieľané s každým v skupine.\n\nAdresáre je možné konfigurovať z *Adresáre skupiny* v nastaveniach správcu.\n\nPo vytvorení adresára môže správca poskytnúť prístup k adresáru jednej alebo viacerým skupinám, riadiť ich povolenia na zápis/zdieľanie a prideliť adresáru kvótu.",
    "Group folder" : "Skupinový priečinok",
    "Open group folder" : "Otvoriť adresár skupiny",
    "List of group folders." : "Zoznam skupinových adresárov.",
    "No group folders yet" : "Žiadne skupinové adresáre",
    "Group folders will show up here" : "Skupinové adresáre sa zobrazia tu",
    "Group folder admin delegation" : "Delegácia správcu skupinového adresára",
    "They will have access to all group folders." : "Budú mať prístup ku všetkým skupinovým adresárom.",
    "They will only have access to group folders for which they have advanced permissions." : "Budú mať prístup iba k skupinovým adresárom, pre ktoré majú pokročilé oprávnenia.",
    "Admin configured folders shared with everyone in a team" : "Správca nakonfiguroval adresáre zdieľané s každým v tíme",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Správca nakonfiguroval adresáre zdieľané s každým v tíme.\n\nAdresáre je možné konfigurovať z *Tímových adresárov* v nastaveniach správcu.\n\nPo vytvorení adresára môže správca poskytnúť prístup k adresáru jednému alebo viacerým tímom, ovládať ich povolenia na zápis/zdieľanie a prideliť adresáru kvótu.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Administrátorom nakonfigurované adresáre zdieľané s každým v tíme.\n\nAdresáre je možné konfigurovať z *Tímových adresárov* v nastaveniach administrátora.\n\nPo vytvorení adresára môže administrátor poskytnúť prístup k adresáru jednému alebo viacerým tímom, ovládať ich povolenia na zápis/zdieľanie a prideliť adresáru kvótu.\nOd Hub 10/Nextcloud 31 musí byť administrátor súčasťou tímu, aby mu mohol priradiť adresár Team."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
